import { Octokit } from '@octokit/rest';
import { request } from '@octokit/request';
import { PromiseValue } from 'type-fest';
import { OctokitResponse } from '@octokit/types';
declare type OctokitType = InstanceType<typeof Octokit>;
declare type PullsListResponseItems = PromiseValue<ReturnType<InstanceType<typeof Octokit>['pulls']['list']>>['data'];
declare type IssuesListResponseItem = PromiseValue<ReturnType<InstanceType<typeof Octokit>['issues']['get']>>['data'];
export declare type ReleaseCreateResponse = PromiseValue<ReturnType<InstanceType<typeof Octokit>['repos']['createRelease']>>['data'];
declare type RequestBuilderType = typeof request;
declare type DefaultFunctionType = RequestBuilderType['defaults'];
declare type RequestFunctionType = ReturnType<DefaultFunctionType>;
import { Commit, PREdge } from './graphql-to-commits';
import { Update } from './updaters/update';
export interface OctokitAPIs {
    graphql: Function;
    request: RequestFunctionType;
    octokit: OctokitType;
}
interface GitHubOptions {
    defaultBranch?: string;
    token?: string;
    owner: string;
    repo: string;
    apiUrl?: string;
    proxyKey?: string;
    octokitAPIs?: OctokitAPIs;
}
export interface GitHubTag {
    name: string;
    sha: string;
    version: string;
}
export interface GitHubReleasePR {
    number: number;
    sha: string;
    version: string;
}
export interface GitHubFileContents {
    sha: string;
    content: string;
    parsedContent: string;
}
export interface GitHubPR {
    branch: string;
    fork: boolean;
    version: string;
    title: string;
    body: string;
    sha: string;
    updates: Update[];
    labels: string[];
}
export declare class GitHub {
    defaultBranch?: string;
    octokit: OctokitType;
    request: RequestFunctionType;
    graphql: Function;
    token: string | undefined;
    owner: string;
    repo: string;
    apiUrl: string;
    proxyKey?: string;
    constructor(options: GitHubOptions);
    private graphqlRequest;
    private decoratePaginateOpts;
    commitsSinceSha(sha: string | undefined, perPage?: number, labels?: boolean, path?: string | null): Promise<Commit[]>;
    private commitsWithFiles;
    private commitsWithLabels;
    pullRequestFiles(num: number, cursor: string, maxFilesChanged?: number): Promise<PREdge>;
    getTagSha(name: string): Promise<string>;
    latestTag(prefix?: string, preRelease?: boolean, branchPrefix?: string): Promise<GitHubTag | undefined>;
    latestTagFallback(prefix?: string, preRelease?: boolean): Promise<{
        name: string;
        sha: string;
        version: string;
    } | undefined>;
    private allTags;
    findMergedReleasePR(labels: string[], perPage?: number, prefix?: string | undefined, preRelease?: boolean): Promise<GitHubReleasePR | undefined>;
    private hasAllLabels;
    findOpenReleasePRs(labels: string[], perPage?: number): Promise<PullsListResponseItems>;
    addLabels(labels: string[], pr: number): Promise<OctokitResponse<any, number>>;
    findExistingReleaseIssue(title: string, labels: string[]): Promise<IssuesListResponseItem | undefined>;
    openPR(options: GitHubPR): Promise<number | undefined>;
    private getChangeSet;
    private getBaseLabel;
    getDefaultBranch(): Promise<string>;
    closePR(prNumber: number): Promise<void>;
    static qualifyRef(refName: string): string;
    getFileContentsWithSimpleAPI(path: string, branch: string): Promise<GitHubFileContents>;
    getFileContentsWithDataAPI(path: string, branch: string): Promise<GitHubFileContents>;
    getFileContents(path: string): Promise<GitHubFileContents>;
    getFileContentsOnBranch(path: string, branch: string): Promise<GitHubFileContents>;
    createRelease(packageName: string, tagName: string, sha: string, releaseNotes: string): Promise<ReleaseCreateResponse>;
    removeLabels(labels: string[], prNumber: number): Promise<void>;
    findFilesByFilename(filename: string): Promise<string[]>;
}
export {};
