"use strict";
// Copyright 2019 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReleasePRFactory = void 0;
const releasers_1 = require("./releasers");
const node_1 = require("./releasers/node");
const python_1 = require("./releasers/python");
const ruby_1 = require("./releasers/ruby");
const simple_1 = require("./releasers/simple");
const go_yoshi_1 = require("./releasers/go-yoshi");
const terraform_module_1 = require("./releasers/terraform-module");
class ReleasePRFactory {
    static build(releaseType, options) {
        const releaseOptions = {
            ...options,
            ...{ releaseType },
        };
        return new (ReleasePRFactory.class(releaseType))(releaseOptions);
    }
    // Return a ReleasePR class, based on the release type, e.g., node, python:
    static class(releaseType) {
        const releasers = releasers_1.getReleasers();
        const releaser = releasers[releaseType];
        if (!releaser) {
            throw Error('unknown release type');
        }
        return releaser;
    }
    // For the benefit of WebPack, we provide a static factory for a subset
    // of the releasers available in the release please GitHub action:
    static buildStatic(releaseType, options) {
        const releaseOptions = {
            ...options,
            ...{ releaseType },
        };
        switch (releaseType) {
            case 'node':
                return new node_1.Node(releaseOptions);
            case 'python':
                return new python_1.Python(releaseOptions);
            case 'ruby':
                return new ruby_1.Ruby(releaseOptions);
            case 'simple':
                return new simple_1.Simple(releaseOptions);
            case 'terraform-module':
                return new terraform_module_1.TerraformModule(releaseOptions);
            case 'go':
                return new go_yoshi_1.GoYoshi(releaseOptions);
            default:
                throw Error('unknown release type');
        }
    }
}
exports.ReleasePRFactory = ReleasePRFactory;
//# sourceMappingURL=release-pr-factory.js.map