import { ConventionalCommits } from './conventional-commits';
import { GitHub, GitHubTag, OctokitAPIs } from './github';
import { Commit } from './graphql-to-commits';
import { Update } from './updaters/update';
export interface BuildOptions {
    bumpMinorPreMajor?: boolean;
    defaultBranch?: string;
    fork?: boolean;
    label?: string;
    token?: string;
    repoUrl: string;
    packageName: string;
    monorepoTags?: boolean;
    path?: string;
    releaseAs?: string;
    apiUrl: string;
    proxyKey?: string;
    snapshot?: boolean;
    lastPackageVersion?: string;
    octokitAPIs?: OctokitAPIs;
    versionFile?: string;
}
export interface ReleasePROptions extends BuildOptions {
    releaseType: string;
    changelogSections?: [];
}
export interface ReleaseCandidate {
    version: string;
    previousTag?: string;
}
interface GetCommitsOptions {
    sha?: string;
    perPage?: number;
    labels?: boolean;
    path?: string;
}
export interface OpenPROptions {
    sha: string;
    changelogEntry: string;
    updates: Update[];
    version: string;
    includePackageName: boolean;
}
export declare class ReleasePR {
    static releaserName: string;
    apiUrl: string;
    defaultBranch?: string;
    labels: string[];
    fork: boolean;
    gh: GitHub;
    bumpMinorPreMajor?: boolean;
    repoUrl: string;
    token: string | undefined;
    path?: string;
    packageName: string;
    monorepoTags: boolean;
    releaseAs?: string;
    proxyKey?: string;
    snapshot?: boolean;
    lastPackageVersion?: string;
    changelogSections?: [];
    constructor(options: ReleasePROptions);
    run(): Promise<number | undefined>;
    protected _run(): Promise<number | undefined>;
    protected supportsSnapshots(): boolean;
    protected closeStaleReleasePRs(currentPRNumber: number, includePackageName?: boolean): Promise<void>;
    protected defaultInitialVersion(): string;
    static lookupPackageName(gh: GitHub): Promise<string | undefined>;
    static tagSeparator(): string;
    protected coerceReleaseCandidate(cc: ConventionalCommits, latestTag: GitHubTag | undefined, preRelease?: boolean): Promise<ReleaseCandidate>;
    protected commits(opts: GetCommitsOptions): Promise<Commit[]>;
    protected gitHubInstance(octokitAPIs?: OctokitAPIs): GitHub;
    protected openPR(options: OpenPROptions): Promise<number | undefined>;
    protected changelogEmpty(changelogEntry: string): boolean;
    addPath(file: string): string;
}
export {};
