"use strict";
// Copyright 2019 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.getReleaserNames = exports.getReleasers = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
// dynamically load all the releasers in the folder, and index based on their
// releaserName property:
function getReleasers() {
    const releasers = {};
    const root = path_1.dirname(require.resolve('./'));
    for (const file of fs_1.readdirSync(root, { withFileTypes: true })) {
        if (file.isFile() &&
            !file.name.match(/.*\.ts.*/) &&
            !file.name.match(/.*\.map$/) &&
            !file.name.match(/index\.js/)) {
            const obj = require(`./${file.name}`);
            const releaser = obj[Object.keys(obj)[0]];
            releasers[releaser.releaserName] = releaser;
        }
    }
    return releasers;
}
exports.getReleasers = getReleasers;
function getReleaserNames() {
    const releasers = getReleasers();
    return Object.keys(releasers).map(key => {
        const releaser = releasers[key];
        return releaser.releaserName;
    });
}
exports.getReleaserNames = getReleaserNames;
//# sourceMappingURL=index.js.map