"use strict";
// Copyright 2020 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.isStableArtifact = void 0;
const VERSIONED_ARTIFACT_REGEX = /^.*-(v\d+[^-]*)$/;
const VERSION_REGEX = /^v\d+(.*)$/;
/**
 * Returns true if the artifact should be considered stable
 * @param artifact name of the artifact to check
 */
function isStableArtifact(artifact) {
    const match = artifact.match(VERSIONED_ARTIFACT_REGEX);
    if (!match) {
        // The artifact does not have a version qualifier at the end
        return true;
    }
    const versionMatch = match[1].match(VERSION_REGEX);
    if (versionMatch && versionMatch[1]) {
        // The version is not stable (probably alpha/beta/rc)
        return false;
    }
    return true;
}
exports.isStableArtifact = isStableArtifact;
//# sourceMappingURL=stability.js.map