"use strict";
// Copyright 2019 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.RootComposer = void 0;
const checkpoint_1 = require("../util/checkpoint");
class RootComposer {
    constructor(options) {
        this.create = false;
        this.path = options.path;
        this.changelogEntry = options.changelogEntry;
        this.version = options.version;
        this.versions = options.versions;
        this.packageName = options.packageName;
    }
    updateContent(content) {
        if (!this.versions || this.versions.size === 0) {
            checkpoint_1.checkpoint(`no updates necessary for ${this.path}`, checkpoint_1.CheckpointType.Failure);
            return content;
        }
        const parsed = JSON.parse(content);
        if (this.versions) {
            // eslint-disable-next-line prefer-const
            for (let [key, version] of this.versions.entries()) {
                version = version || '1.0.0';
                checkpoint_1.checkpoint(`updating ${key} from ${parsed.replace[key]} to ${version}`, checkpoint_1.CheckpointType.Success);
                parsed.replace[key] = version;
            }
        }
        return JSON.stringify(parsed, null, 4) + '\n';
    }
}
exports.RootComposer = RootComposer;
//# sourceMappingURL=root-composer.js.map